@@ -1,4 +1,4 @@
-package Test::FilterDocBook;
+package Test::Filter;
 use strict;
 use warnings;
 use Test::More;
@@ -12,12 +12,11 @@ sub on_start_element {
     }
     return $el;
 }
-
 1;
 
 package Perl6::Pod::To::DocBook;
 
-#$Id$
+#$Id: DocBook.pm 582 2009-07-26 09:04:44Z zag $
 
 =pod
 
@@ -62,11 +61,10 @@ Result xml:
 use strict;
 use warnings;
 use Perl6::Pod::To::XML;
+use XML::SAX::Writer;
 use Perl6::Pod::Parser::AddHeadLevels;
 use Perl6::Pod::To::DocBook::ProcessHeads;
 use Perl6::Pod::Parser::ListLevels;
-use Perl6::Pod::Parser::Doformatted;
-use Perl6::Pod::Parser::NestedAttr;
 use XML::ExtOn('create_pipe');
 use base qw/Perl6::Pod::To::XML/;
 use constant POD_URI => 'http://perlcabal.org/syn/S26.html';
@@ -78,9 +76,9 @@ sub new {
     $self->{out_put} =
       create_pipe( 'Perl6::Pod::To::DocBook::ProcessHeads', $self->{out_put} );
     return create_pipe(
-        'Perl6::Pod::Parser::NestedAttr', 'Perl6::Pod::Parser::Doformatted',
-        'Perl6::Pod::Parser::ListLevels', 'Perl6::Pod::Parser::AddHeadLevels',
-        'Test::FilterDocBook',            $self
+        'Perl6::Pod::Parser::ListLevels',
+        'Perl6::Pod::Parser::AddHeadLevels',
+        'Test::Filter', $self
     );
 }
 
@@ -139,11 +137,7 @@ sub process_element {
         }
     }
     else {
-        #skip all _UPPER_CASE_SPESIAL_ tags
-        my $lname = $elem->local_name();
-        if (  $lname eq uc($lname) and $lname=~ /^_+.*_$/ ) {
-            return [ $self->_make_elements(@_) ]
-        }
+
         #make characters from unhandled texts
         my @out_content = ();
         for (@_) {
@@ -186,7 +180,7 @@ sub on_end_block {
     return $el unless $el->isa('Perl6::Pod::Block');
     my $content = exists $el->{_CONTENT_} ? $el->{_CONTENT_} : undef;
     my $data = $self->__handle_export( $el, @$content );
-    my $cel = $self->current_root_element;
+    my $cel = $self->current_element;
     if ($cel) {
         push @{ $cel->{_CONTENT_} }, ref($data) eq 'ARRAY' ? @$data : $data;
         return;
@@ -198,12 +192,20 @@ sub on_end_block {
     return $el;
 }
 
-sub export_block__DEFN_TERM_ {
+sub export_block_item {
     my ( $self, $el, @p ) = @_;
-    return $self->mk_element('term')->add_content( $self->_make_events(@p) );
+    my $elem =
+      $self->mk_element('listitem')
+      ->add_content(
+        $self->mk_element('para')->add_content( $self->mk_characters(@p) ) );
+
+    #add PDO attr for use in export_block_itemlist
+    #for varlistentry
+    $elem->{POD} = $el->get_attr;
+    return $elem;
 }
 
-sub export_block__ITEM_ENTRY_ {
+sub export_block_itemlist {
     my ( $self, $el, @p ) = @_;
     my $attr = $el->attrs_by_name;
     my ( $list_name, $items_name ) = @{
@@ -213,66 +215,39 @@ sub export_block__ITEM_ENTRY_ {
             definition => [ 'variablelist', 'listitem' ]
         }->{ $attr->{listtype} }
       };
-    unless ( $attr->{is_multi_para} ) {
-        @p =
-          ( $self->mk_element('para')->add_content( $self->_make_events(@p) ) );
-    }
-    my $res =
-      $self->mk_element($items_name)->add_content( $self->_make_events(@p) );
-    return $res;
+    my $list = $self->mk_element($list_name);
+    foreach (@p) {
+        next unless ref $_;
+        my $lname = $_->local_name;
+        if ( $lname eq 'listitem' ) {
+            $_->local_name($items_name);
 
-}
+            #if variable list, then add varlistentry
+            if ( $list->local_name eq 'variablelist' ) {
+                my ($term) = @{ $_->{POD}->{term} };
+
+                my $var_entry =
+                  $self->mk_element('varlistentry')
+                  ->add_content( $self->mk_element('term')
+                      ->add_content( $self->mk_characters($term) ) );
+                $var_entry->add_content($_);
+                $list->add_content($var_entry);
+
+            }
+            else {
+                $list->add_content($_);
+            }
 
-sub export_block__LIST_ITEM_ {
-    my ( $self, $el, @p ) = @_;
-    
-    #check type of list
-    my $attr = $el->attrs_by_name;
-    my ( $list_name, $items_name ) = @{
-        {
-            ordered    => [ 'orderedlist',  'listitem' ],
-            unordered  => [ 'itemizedlist', 'listitem' ],
-            definition => [ 'variablelist', 'listitem' ]
-        }->{ $attr->{listtype} }
-      };
-    my $res =
-      $self->mk_element($list_name)->add_content( $self->_make_events(@p) );
-    #do nesting
-    my $item_level = $el->attrs_by_name->{item_level} || 1;
-    #add level marker
-    if ( $list_name eq 'itemizedlist' and $item_level > 1) {
-     #get list from http://www.sagehill.net/docbookxsl/Itemizedlists.html
-     my @markers= qw/bullet opencircle box /;
-     $res->attrs_by_name->{mark} = $markers[ ($item_level-1) % 3  ];
-    } elsif ( $list_name eq 'orderedlist'){
-            #set continuation -> continues
-        if ( $attr->{number_start} != 1 ) {
-            #set continuation -> continues
-#            warn Dumper {$el->local_name => $attr};
-           $res->attrs_by_name->{continuation} = 'continues'; 
         }
     }
-    if ( my $count = $item_level -1 ) {
-        for (1..$count) {
-            my $nest =  $self->mk_element('blockquote');
-            $res = $nest->add_content( $res);
-        }
-    }
-    return $res;
+
+    return $list;
 }
 
 sub export_block_NAME {
-    my ( $self, $el, @in ) = @_;
-    return $self->mk_element('title')->add_content( $self->_make_events(@in) );
-}
-
-#for N clean any extra tags
-sub export_block__NOTES_ {
-    return;
-}
-
-sub export_block__NOTE_ {
-    return;
+    my ( $self, $el, $text ) = @_;
+    return $self->mk_element('title')
+      ->add_content( $self->mk_characters($text) );
 }
 
 1;
@@ -289,7 +264,7 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Zahatski Aliaksandr
+Copyright (C) 2009 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
